==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/vo/ContrastanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordContrastanalysistVO;
import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.ContrastanalysisdetailVO;

/**
 * 对比分析表
 * 
 * @author generator
 * 
 */
public class ContrastanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal tenderTotal; // 投标阶段合计
    private java.math.BigDecimal quotaTotal; // 限额设计阶段合计
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算阶段合计
    private java.math.BigDecimal constructionTotal; // 施工图预算阶段合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    private List<ContrastanalysisdetailVO> contrastanalysisdetailEntities = new ArrayList<>(); // 对比分析子表
    private List<RecordContrastanalysistVO> recordContrastanalysistList = new ArrayList<>(); // 历史信息


    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 投标阶段合计
     */
    public java.math.BigDecimal getTenderTotal() {
        return tenderTotal;
    }

    /**
     * 投标阶段合计
     */
    public void setTenderTotal(java.math.BigDecimal tenderTotal) {
        this.tenderTotal = tenderTotal;
    }
    /**
     * 限额设计阶段合计
     */
    public java.math.BigDecimal getQuotaTotal() {
        return quotaTotal;
    }

    /**
     * 限额设计阶段合计
     */
    public void setQuotaTotal(java.math.BigDecimal quotaTotal) {
        this.quotaTotal = quotaTotal;
    }
    /**
     * 设计概算阶段合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算阶段合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 施工图预算阶段合计
     */
    public java.math.BigDecimal getConstructionTotal() {
        return constructionTotal;
    }

    /**
     * 施工图预算阶段合计
     */
    public void setConstructionTotal(java.math.BigDecimal constructionTotal) {
        this.constructionTotal = constructionTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 对比分析子表
      */
    public List<ContrastanalysisdetailVO> getContrastanalysisdetailEntities() {
        return contrastanalysisdetailEntities;
    }

    /**
     * 对比分析子表
     */
    public void setContrastanalysisdetailEntities(List<ContrastanalysisdetailVO> contrastanalysisdetailEntities) {
        this.contrastanalysisdetailEntities = contrastanalysisdetailEntities;
    }

    public List<RecordContrastanalysistVO> getRecordContrastanalysistList() {
        return recordContrastanalysistList;
    }

    public void setRecordContrastanalysistList(List<RecordContrastanalysistVO> recordContrastanalysistList) {
        this.recordContrastanalysistList = recordContrastanalysistList;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220408.085606-74-sources.jar: com/ejianc/business/bedget/vo/ContrastanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordContrastanalysistVO;
import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.ContrastanalysisdetailVO;

/**
 * 对比分析表
 * 
 * @author generator
 * 
 */
public class ContrastanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编码
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.math.BigDecimal tenderTotal; // 投标阶段合计
    private java.math.BigDecimal quotaTotal; // 限额设计阶段合计
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算阶段合计
    private java.math.BigDecimal constructionTotal; // 施工图预算阶段合计
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更

    private java.lang.Long sort; // 序号
    private java.lang.String createTimeShow;
    private java.lang.String billStateStr;
    
    private List<ContrastanalysisdetailVO> contrastanalysisdetailEntities = new ArrayList<>(); // 对比分析子表
    private List<RecordContrastanalysistVO> recordContrastanalysistList = new ArrayList<>(); // 历史信息


    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 投标阶段合计
     */
    public java.math.BigDecimal getTenderTotal() {
        return tenderTotal;
    }

    /**
     * 投标阶段合计
     */
    public void setTenderTotal(java.math.BigDecimal tenderTotal) {
        this.tenderTotal = tenderTotal;
    }
    /**
     * 限额设计阶段合计
     */
    public java.math.BigDecimal getQuotaTotal() {
        return quotaTotal;
    }

    /**
     * 限额设计阶段合计
     */
    public void setQuotaTotal(java.math.BigDecimal quotaTotal) {
        this.quotaTotal = quotaTotal;
    }
    /**
     * 设计概算阶段合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算阶段合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 施工图预算阶段合计
     */
    public java.math.BigDecimal getConstructionTotal() {
        return constructionTotal;
    }

    /**
     * 施工图预算阶段合计
     */
    public void setConstructionTotal(java.math.BigDecimal constructionTotal) {
        this.constructionTotal = constructionTotal;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
     /**
      * 对比分析子表
      */
    public List<ContrastanalysisdetailVO> getContrastanalysisdetailEntities() {
        return contrastanalysisdetailEntities;
    }

    /**
     * 对比分析子表
     */
    public void setContrastanalysisdetailEntities(List<ContrastanalysisdetailVO> contrastanalysisdetailEntities) {
        this.contrastanalysisdetailEntities = contrastanalysisdetailEntities;
    }

    public List<RecordContrastanalysistVO> getRecordContrastanalysistList() {
        return recordContrastanalysistList;
    }

    public void setRecordContrastanalysistList(List<RecordContrastanalysistVO> recordContrastanalysistList) {
        this.recordContrastanalysistList = recordContrastanalysistList;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }
}
